@@ -4,7 +4,7 @@ use strict;
 
 use vars qw ($VERSION);
 
-$VERSION = '0.04';
+$VERSION = '0.05';
 
 use DateTime;
 use DateTime::Format::Builder
@@ -33,6 +33,18 @@ use DateTime::Format::Builder
             postprocess => \&_fix_nano
           },
         ],
+        parse_datetime =>
+        [ { params => [ qw( year month day hour minute second nanosecond) ],
+            regex  => qr/^(\d\d\d\d)-(\d\d)-(\d\d)-(\d\d)\.(\d\d)\.(\d\d)(\.\d+)?$/,
+            extra  => { time_zone => 'floating' },
+            postprocess => \&_fix_nano
+          },
+        { params => [ qw( year month day hour minute second nanosecond) ],
+            regex  => qr/^(\d\d\d\d)-(\d\d)-(\d\d)\s(\d\d):(\d\d):(\d\d)(\.\d+)?$/,
+            extra  => { time_zone => 'floating' },
+            postprocess => \&_fix_nano
+          },
+        ],
       },
     );
 
@@ -66,6 +78,7 @@ sub format_timestamp
     return $self->format_date($dt) . '-' . $dt->hms('.');
 }
 
+*format_datetime = *format_timestamp;
 
 1;
 
